Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(443)

Unified Diff: include/gpu/GrContext.h

Issue 2004433002: Retract GrRenderTarget from GrTestTarget (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Fix bench build Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gm/rectangletexture.cpp ('k') | include/gpu/GrDrawContext.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrContext.h
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index 86c9fa925ffba83e3a9ee33c7dc9306f5c9c6e35..4e2546b6e22eb1975cde146e455aa2e6ac587d6f 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -27,7 +27,6 @@ struct GrContextOptions;
class GrContextThreadSafeProxy;
class GrDrawingManager;
class GrDrawContext;
-class GrDrawTarget;
class GrFragmentProcessor;
class GrGpu;
class GrIndexBuffer;
@@ -354,8 +353,8 @@ public:
const GrResourceProvider* resourceProvider() const { return fResourceProvider; }
GrResourceCache* getResourceCache() { return fResourceCache; }
- // Called by tests that draw directly to the context via GrDrawTarget
- void getTestTarget(GrTestTarget*, GrRenderTarget* rt);
+ // Called by tests that draw directly to the context via GrDrawContext
+ void getTestTarget(GrTestTarget*, sk_sp<GrDrawContext>);
/** Reset GPU stats */
void resetGpuStats() const ;
« no previous file with comments | « gm/rectangletexture.cpp ('k') | include/gpu/GrDrawContext.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698